==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/es_AR.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "El archivo ha sido subido",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Could not write file to disk" : "No se pudo escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "New text file" : "Nuevo archivo de texto",
    "File not found" : "Archivo no encontrado",
    "Text" : "Texto",
    "Nextcloud Assistant" : "Asistente de Nextcloud",
    "Translate" : "Traducir",
    "Reload" : "Recargar",
    "Guest" : "Invitado",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Bold" : "Negrita",
    "Italic" : "Itálico",
    "name" : "nombre",
    "Action" : "Acción",
    "Undo" : "Deshacer",
    "Cannot copy, please copy the link manually" : "No es posible copiar, por favor copia el enlace manualmente",
    "URL" : "URL",
    "Formatting help" : "Ayuda de formato",
    "Select language" : "Seleccionar idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Edit" : "Editar",
    "Source code" : "Código fuente",
    "Done" : "Terminado",
    "Table" : "Tabla",
    "Details" : "Detalles",
    "Add folder description" : "Agregar una descripción a la carpeta",
    "Info" : "Info",
    "Warning" : "Advertencia"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/es_AR.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "El archivo ha sido subido",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Could not write file to disk" : "No se pudo escribir el archivo en el disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "New text file" : "Nuevo archivo de texto",
    "File not found" : "Archivo no encontrado",
    "Text" : "Texto",
    "Reload" : "Recargar",
    "Guest" : "Invitado",
    "you" : "usted",
    "edit" : "editar",
    "Copy link" : "Copiar link",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Bold" : "Negrita",
    "Italic" : "Itálico",
    "name" : "nombre",
    "Action" : "Acción",
    "Undo" : "Deshacer",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Save" : "Guardar",
    "Formatting help" : "Ayuda de formato",
    "Translate" : "Traducir",
    "Nextcloud Assistant" : "Asistente de Nextcloud",
    "Select language" : "Seleccionar idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Edit" : "Editar",
    "Upload" : "Cargar",
    "Source code" : "Código fuente",
    "Done" : "Terminado",
    "Table" : "Tabla",
    "Details" : "Detalles",
    "Choose" : "Elige",
    "Add folder description" : "Agregar una descripción a la carpeta",
    "Cannot copy, please copy the link manually" : "No es posible copiar, por favor copia el enlace manualmente"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
